#'@name IUCN
#'@aliases IUCN
#'@docType data
#'@title IUCN avaliation for frogs of Phyllomedusa genus 
#'@usage data(IUCN)
#'@description Result of the function \code{\link{lets.iucn}} 
#'applied to Southern American frog genera Phyllomedusa in 2014. 

NULL

#'@name PAM
#'@aliases PAM
#'@docType data
#'@title PresenceAbsence object for frogs of Phyllomedusa genus
#'@usage data(PAM)
#'@description PresenceAbsence object obtained using the function \code{\link{lets.presab}} 
#'in the Geographic distribution of the Southern American frog genus \link{Phyllomedusa}.
#'@source IUCN - \url{https://www.iucnredlist.org/}. 2014.

NULL

#'@name Phyllomedusa
#'@aliases Phyllomedusa
#'@docType data
#'@title Geographic distribution of Phyllomedusa genus
#'@usage data(Phyllomedusa)
#'@description Geographic distribution of the Southern American frog genera Phyllomedusa. 
#'Data was modfied from IUCN (\url{https://www.iucnredlist.org/}, downloaded in 05/2014). 
#'There are 32 species and 46 polygons.
#'@source IUCN - \url{https://www.iucnredlist.org/}. 2014.

NULL

#'@name temp
#'@aliases temp
#'@docType data
#'@title Avarege temperature raster for the world.
#'@usage data(temp)
#'@description Average temperature raster in Celsius degrees(multiplied by 100) 
#'for the world in 10 arc min of resolution. Data was modfied from 
#'WorldClim (\url{https://worldclim.com/}, downloaded in 05/2014).
#'@source Hijmans, R.J., S.E. Cameron, J.L. Parra, P.G. Jones and A. Jarvis, 2005. 
#'Very high resolution interpolated climate surfaces for global land areas. 
#'International Journal of Climatology 25: 1965-1978.

NULL



#'@name wrld_simpl
#'@aliases wrld_simpl
#'@docType data
#'@title Simplified world country polygons
#'@usage data(temp)
#'@description Shapefile in sf format. The object was obtained from maptools
#'  package and converted to sf.
#'@source Originally
#'  “https://mappinghacks.com/data/TM_WORLD_BORDERS_SIMPL-0.2.zip”, 
#'  now available from
#'  https://github.com/nasa/World-Wind-Java/tree/master/WorldWind/testData/shapefiles



NULL
